@@ -2,6 +2,6 @@ from .logger import logger, debug, info, error, exception, level
 from .net import (
     get_ip_adr,
 )
-from .shell import shell, bash
+from .shell import shell, bash, pipe
 from .ssh import SSH, ParamSSH
 from .config import get_app_config
