@@ -1,6 +1,9 @@
 class Primes:
     def __init__(self):
         self.primes = [3]
+        '''
+        self.primes = array('L', [3]) # ! bigger and slower !
+        '''
 
     def next(self):
         primes = self.primes
@@ -14,6 +17,14 @@ class Primes:
                 primes.append(n)
                 return n
 
+    def __getitem__(self, i):
+        if i<0: raise OverflowError
+        if i==0: return 2
+        primes = self.primes
+        nxt = self.next
+        while len(primes)<i: nxt()
+        return primes[i-1]
+
     def __iter__(self):
         yield 2
         for p in self.primes:
