@@ -1,7 +1,8 @@
 from functools import partial
 from subprocess import (
-    PIPE,
     CalledProcessError,
+    PIPE,
+    Popen,
     run,
 )
 
@@ -34,4 +35,19 @@ def shell(script, shell, color=False):
     return ret, out, err
 
 
+def pipe(*cmds):
+    prev = None
+    for cmd in cmds:
+        if prev:
+            proc = Popen(cmd.split(), stdin=prev.stdout, stdout=PIPE)
+        else:
+            proc = Popen(cmd.split(), stdout=PIPE)
+        prev = proc
+
+    for line in proc.stdout.read().decode().strip().split('\n'):
+        yield line.strip()
+
+
 bash = partial(shell, shell='/bin/bash')
+
+
