@@ -30,7 +30,10 @@ class Config:
                         else:
                             items[key] = value
                 hosts[host] = items
-        return hosts.items()
+        return hosts
+
+    def __iter__(self):
+        return iter(self.parse().items())
 
 
 class Host:
@@ -156,7 +159,7 @@ class Hosts:
     def __init__(self, ssh):
         self.ssh = ssh
         self.all = dict()
-        for name, items in ssh.config.parse():
+        for name, items in ssh.config:
             host = Host(ssh, name, items)
             setattr(self, name, host)
             self.all[name] = host
